@@ -5,6 +5,7 @@ my ($sha_ok, $bcrypt_ok);
 BEGIN {
   $sha_ok    = eval 'require Digest' && eval 'require Digest::SHA;';
   $bcrypt_ok = eval 'require Crypt::Eksblowfish::Bcrypt';
+  $pgp_ok    = eval 'require Crypt::OpenPGP';
 }
 
 use base qw/DBIx::Class/;
@@ -32,6 +33,7 @@ if( $sha_ok ) {
     (
      sha1_hex => {
                   data_type => 'char',
+                  is_nullable => 1,
                   size      => 40,
                   encode_column => 1,
                   encode_class  => 'Digest',
@@ -43,6 +45,7 @@ if( $sha_ok ) {
                  },
      sha1_b64 => {
                   data_type => 'char',
+                  is_nullable => 1,
                   size      => 27,
                   encode_column => 1,
                   encode_class  => 'Digest',
@@ -53,6 +56,7 @@ if( $sha_ok ) {
                },
      sha256_hex => {
                     data_type => 'char',
+                    is_nullable => 1,
                     size      => 64,
                     encode_column => 1,
                     encode_class  => 'Digest',
@@ -60,6 +64,7 @@ if( $sha_ok ) {
                    },
      sha256_b64 => {
                     data_type => 'char',
+                    is_nullable => 1,
                     size      => 43,
                     accessor  => 'sha256b64',
                     encode_column => 1,
@@ -67,6 +72,7 @@ if( $sha_ok ) {
                    },
      sha256_b64_salted => {
                            data_type => 'char',
+                           is_nullable => 1,
                            size      => 57,
                            encode_column => 1,
                            encode_class  => 'Digest',
@@ -81,6 +87,7 @@ if( $bcrypt_ok ){
     (
      bcrypt_1 => {
                   data_type => 'text',
+                  is_nullable => 1,
                   size => 60,
                   encode_column => 1,
                   encode_class  => 'Crypt::Eksblowfish::Bcrypt',
@@ -88,6 +95,7 @@ if( $bcrypt_ok ){
                  },
      bcrypt_2 => {
                   data_type => 'text',
+                  is_nullable => 1,
                   size => 59,
                   encode_column => 1,
                   encode_class  => 'Crypt::Eksblowfish::Bcrypt',
@@ -97,6 +105,49 @@ if( $bcrypt_ok ){
      );
 }
 
+if( $pgp_ok ){
+    my $pgp_conf = {
+        SecRing => "$FindBin::Bin/secring.gpg",
+        PubRing => "$FindBin::Bin/pubring.gpg",
+    };
+    __PACKAGE__->add_columns(
+        pgp_col_passphrase => {
+            data_type => 'text',
+            is_nullable => 1,
+            encode_column => 1,
+            encode_class  => 'Crypt::OpenPGP',
+            encode_args => {
+                passphrase => 'Secret Words',
+                armour     => 1
+            },
+            encode_check_method => 'decrypt_pgp_passphrase',
+        },
+        pgp_col_key => {
+            data_type => 'text',
+            is_nullable => 1,
+            encode_column => 1,
+            encode_class  => 'Crypt::OpenPGP',
+            encode_args => {
+                recipient => '1B8924AA',
+                pgp_args   => $pgp_conf,
+                armour     => 1
+            },
+            encode_check_method => 'decrypt_pgp_key',
+        },
+        pgp_col_key_ps => {
+            data_type => 'text',
+            is_nullable => 1,
+            encode_column => 1,
+            encode_class  => 'Crypt::OpenPGP',
+            encode_args => {
+                recipient => '7BEF6294',
+                pgp_args   => $pgp_conf,
+                armour     => 1
+            },
+            encode_check_method => 'decrypt_pgp_key_ps',
+        },
+    );
+}
 
 __PACKAGE__->set_primary_key('id');
 
